package example.controller;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.OutputStream;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@WebServlet("/download")
public class FileDownloadServlet extends HttpServlet {
    private static final long serialVersionUID = 1L;

    // 设置文件上传路径（webapp/uploads）
    private static final String UPLOAD_DIRECTORY = "uploads";

    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        // 动态解析 webapp/uploads 的路径
        String uploadPath = getServletContext().getRealPath("/") + UPLOAD_DIRECTORY;

        // 获取请求的文件名
        String fileName = request.getParameter("file");
        if (fileName == null || fileName.isEmpty()) {
            response.getWriter().println("File parameter is missing");
            return;
        }

        // 构造文件的完整路径
        File file = new File(uploadPath + File.separator + fileName);

        // 检查文件是否存在
        if (!file.exists()) {
            response.getWriter().println("File not found: " + fileName);
            return;
        }

        // 设置响应的内容类型
        response.setContentType(getServletContext().getMimeType(file.getName()));
        response.setContentLength((int) file.length());
        response.setHeader("Content-Disposition", "inline; filename=\"" + fileName + "\"");

        // 读取文件并写入到响应输出流
        try (FileInputStream fis = new FileInputStream(file);
             OutputStream os = response.getOutputStream()) {
            byte[] buffer = new byte[4096];
            int bytesRead;
            while ((bytesRead = fis.read(buffer)) != -1) {
                os.write(buffer, 0, bytesRead);
            }
        }
    }
}
